@@ -23,11 +23,12 @@
 #include "config.h"
 #endif
 
-#include "_stdint.h"
+#ifdef HAVE_STDINT_H
+#include <stdint.h>
+#endif
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
 #include <string.h>
 #include <errno.h>
 
@@ -163,8 +164,7 @@ gst_dvd_read_src_class_init (GstDvdReadSrcClass * klass)
       g_param_spec_int ("angle", "angle", "angle",
           1, 999, 1, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
-  gst_element_class_add_pad_template (gstelement_class,
-      gst_static_pad_template_get (&srctemplate));
+  gst_element_class_add_static_pad_template (gstelement_class, &srctemplate);
 
   gst_element_class_set_static_metadata (gstelement_class, "DVD Source",
       "Source/File/DVD",
@@ -559,6 +559,7 @@ gst_dvd_read_src_goto_title (GstDvdReadSrc * src, gint title, gint angle)
       lang_code[0] = (u->lang_code >> 8) & 0xff;
       lang_code[1] = u->lang_code & 0xff;
       gst_structure_set (s, t, G_TYPE_STRING, lang_code, NULL);
+      g_free (t);
       t = g_strdup_printf ("subpicture-%d-stream", i);
       gst_structure_set (s, t, G_TYPE_INT, (int) sid, NULL);
       g_free (t);
@@ -1363,7 +1364,7 @@ gst_dvd_read_src_make_clut_change_event (GstDvdReadSrc * src,
   }
 
   /* Create the DVD event and put the structure into it. */
-  return gst_event_new_custom (GST_EVENT_CUSTOM_DOWNSTREAM, structure);
+  return gst_event_new_custom (GST_EVENT_CUSTOM_DOWNSTREAM_STICKY, structure);
 }
 
 static gint64
